@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/s3-crt/S3Crt_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/s3-crt/S3Crt_EXPORTS.h>
 
-namespace Aws
-{
-namespace S3Crt
-{
-namespace Model
-{
-  enum class TaggingDirective
-  {
-    NOT_SET,
-    COPY,
-    REPLACE
-  };
+namespace Aws {
+namespace S3Crt {
+namespace Model {
+enum class TaggingDirective { NOT_SET, COPY, REPLACE };
 
-namespace TaggingDirectiveMapper
-{
+namespace TaggingDirectiveMapper {
 AWS_S3CRT_API TaggingDirective GetTaggingDirectiveForName(const Aws::String& name);
 
 AWS_S3CRT_API Aws::String GetNameForTaggingDirective(TaggingDirective value);
-} // namespace TaggingDirectiveMapper
-} // namespace Model
-} // namespace S3Crt
-} // namespace Aws
+}  // namespace TaggingDirectiveMapper
+}  // namespace Model
+}  // namespace S3Crt
+}  // namespace Aws
