@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/s3/S3_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/s3/S3_EXPORTS.h>
 
-namespace Aws
-{
-namespace S3
-{
-namespace Model
-{
-  enum class SseKmsEncryptedObjectsStatus
-  {
-    NOT_SET,
-    Enabled,
-    Disabled
-  };
+namespace Aws {
+namespace S3 {
+namespace Model {
+enum class SseKmsEncryptedObjectsStatus { NOT_SET, Enabled, Disabled };
 
-namespace SseKmsEncryptedObjectsStatusMapper
-{
+namespace SseKmsEncryptedObjectsStatusMapper {
 AWS_S3_API SseKmsEncryptedObjectsStatus GetSseKmsEncryptedObjectsStatusForName(const Aws::String& name);
 
 AWS_S3_API Aws::String GetNameForSseKmsEncryptedObjectsStatus(SseKmsEncryptedObjectsStatus value);
-} // namespace SseKmsEncryptedObjectsStatusMapper
-} // namespace Model
-} // namespace S3
-} // namespace Aws
+}  // namespace SseKmsEncryptedObjectsStatusMapper
+}  // namespace Model
+}  // namespace S3
+}  // namespace Aws
